"""
Aws pinpoint sms python library.
"""

__version__ = "0.0.5"

from .sms_service import GsmService
from .mail_service import EMailService
